CallConferenceEvent class

Conference state changed

Inheritance

Constructors

CallConferenceEvent(Call call)
Constructor
const

Properties

call → Call
Еhe call this event refers to
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited