CallDisconnectedEvent class

Call ended

Inheritance

Constructors

CallDisconnectedEvent(Call call, {required int duration, required CallDisconnectReason disconnectReason})
Constructor
const

Properties

call → Call
Еhe call this event refers to
finalinherited
disconnectReason → CallDisconnectReason
The reasons for a disconnection of a call.
final
duration → int
Duration of the call
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited