CallErrorEvent class

An error occured

Inheritance

Constructors

CallErrorEvent(Call call, {required CallError error, required String message})
Constructor
const

Properties

call → Call
Еhe call this event refers to
finalinherited
error → CallError
Error type
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Description for error
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited