AndroidNotificationConfiguration class

Notifications configuration for Android

Constructors

AndroidNotificationConfiguration({String? appActivityClass, String? callActivityClass, String? defaultIconName, String? defaultContactIconName, bool? enableRingtone})
Constructor

Properties

appActivityClass ↔ String?
Application activity class
getter/setter pair
callActivityClass ↔ String?
Call activity class
getter/setter pair
defaultContactIconName ↔ String?
Contact icon name
getter/setter pair
defaultIconName ↔ String?
Icon for call
getter/setter pair
enableRingtone ↔ bool?
Enable ringtone for incoming calls (disabled by default)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert AndroidNotificationConfiguration to dictionary form
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited