CallKitConfiguration class

CallKit configuration for iOS

Constructors

CallKitConfiguration({String? iconTemplateImageResource, String? ringtoneSound, bool? includeInRecents, bool? dtmfEnabled})
Constructor

Properties

dtmfEnabled ↔ bool?
Show DTMF section in calls (disabled by default)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconTemplateImageResource ↔ String?
Icon image
getter/setter pair
includeInRecents ↔ bool?
Show calls in recent calls list Must be YES to show
getter/setter pair
ringtoneSound ↔ String?
Ringtone sound file name
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert AndroidNotificationConfiguration to dictionary form
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited