LogConfiguration class

Logger configuration

Constructors

LogConfiguration({LogLevel? logLevel, String? path, int? maxFileCount, int? maxFileSize, bool? newLogOnStart})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
logLevel ↔ LogLevel?
Logging level
getter/setter pair
maxFileCount ↔ int?
Maximum log files count
getter/setter pair
maxFileSize ↔ int?
Maximum size of log file
getter/setter pair
newLogOnStart ↔ bool?
Create new log files on app start
getter/setter pair
path ↔ String?
Directory where log files be
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert LogConfiguration to dictionary form
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited